#ifndef C_P1CameraCommonNotificationEvent_h
#define C_P1CameraCommonNotificationEvent_h

#include "C_P1CameraCommonStructs.h"
#include "C_P1CameraCommonProperties.h"
#include "C_P1CameraCommonLinkage.h"

#include <string>

namespace P1
{
namespace CameraSdk
{

struct EXPORT_API CameraInfo
{
    bool mIsValid = false;
    TetherConnection mConnectionType = kTetherConnection_Undefined;
    std::string mName;
    std::string mIpV4;
    std::string mSerial;
    
    static const CameraInfo Invalid;
};

struct EXPORT_API NotificationEvent
{
    CameraId mCameraId = -1;
    NotificationType mNotificationType = kNotificationTypeUndefined;

    // Depending on mNotificationType one of these are filled:
    uint32_t mPropertyId = 0;
    CameraEventId mCameraEventId = kCameraEventUndefined;
    SdkEventId mSdkEventId = kSdkEventUndefined;
    CameraInfo mSdkCameraInfo = CameraInfo::Invalid; // valid only if event is CameraFound or CameraRemoved
    
    // if Type is cameraEvent and cameraEventId is ImageTransfer type
    int8_t mTransferProgressPercent = -1; // valid value is between 0 and 100

    
    bool HasCameraId();

    bool operator==(const NotificationEvent& other) const;
    
    static NotificationEvent CreateProgressNotification(CameraEventId type, CameraId camId, int8_t progressValue);
    
    std::string ToString() const;
};

} // CameraSdk
} // P1

#endif /* C_P1CameraCommonNotificationEvent_h */
