#ifndef P1CAMERA_IMAGE_META_HPP
#define P1CAMERA_IMAGE_META_HPP

#include <cstdint>
#include <string>
#include <memory>

#include "C_P1CameraCommonDefs.h"
#include "C_P1CameraCommonStructs.h"
#include "C_P1CameraCommonLinkage.h"

namespace P1
{
namespace CameraSdk
{

    /**
     * @brief In-memory buffer reference to an IIQ file
     */
    struct EXPORT_API IIQImageFile
    {
        uint32_t size = 0;
        std::shared_ptr<const uint8_t> data;
        std::string filename;
    };

    struct EXPORT_API LiveViewImage
    {
        uint32_t imageSize = 0;
        std::shared_ptr<const uint8_t> imageData;
        uint32_t width = 0;
        uint32_t height = 0;
        uint32_t pixelSize = 0;
        ValueRect sourceCrop;
        ValueRect requestedCrop;
        ValueArea sourceFullImageSize;
        LiveViewBitmapFormat format = kLiveViewFormat_UNDEFINED;

        std::string ToString() const;
    };

    class Camera;
    class EXPORT_API ImageMeta
    {
        friend class Camera;
    private:
        void* mImpl;



        ImageMeta& operator=(const ImageMeta& other) = delete;

        ImageMeta();
        ImageMeta(const ImageMeta& other) = delete;

    public:

        ImageMeta(ImageMeta&& other);
        ImageMeta& operator=(ImageMeta&& other);

        virtual uint32_t PixelHeight() const;

        virtual uint32_t PixelWidth() const;

        virtual uint8_t  PixelByteSize() const;

        virtual ~ImageMeta();
    };

} // CameraSdk
} // P1

#endif  // P1CAMERA_IMAGE_META_HPP
